@@ -32,9 +32,10 @@ from rackspace_monitoring.base import (MonitoringDriver, Entity,
                                        Notification, CheckType, Alarm, Check,
                                        NotificationType, AlarmChangelog,
                                        LatestAlarmState, Agent, AgentToken,
-                                       AgentConnection, Metric, DataPoint)
+                                       AgentConnection, Metric, DataPoint,
+                                       Suppression, SuppressionLog)
 
-from libcloud.common.rackspace import AUTH_URL_US
+from libcloud.common.rackspace import AUTH_URL
 from libcloud.common.openstack import OpenStackBaseConnection
 from libcloud.common.openstack import OpenStackDriverMixin
 
@@ -115,13 +116,13 @@ class RackspaceMonitoringConnection(OpenStackBaseConnection):
 
     type = Provider.RACKSPACE
     responseCls = RackspaceMonitoringResponse
-    auth_url = AUTH_URL_US
+    auth_url = AUTH_URL
 
     service_name = 'cloudMonitoring'
     service_type = 'rax:monitor'
 
     def __init__(self, user_id, key, secure=False, ex_force_base_url=None,
-                 ex_force_auth_url=None, ex_force_auth_version='2.0',
+                 ex_force_auth_url=auth_url, ex_force_auth_version='2.0',
                  ex_force_auth_token=None):
         self.accept_format = 'application/json'
         super(RackspaceMonitoringConnection, self).__init__(user_id, key,
@@ -249,7 +250,8 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
               'checks': 'check',
               'notifications': 'notification',
               'notification_plans': 'notificationPlan',
-              'tokens': 'token'}
+              'tokens': 'token',
+              'suppressions': 'suppression'}
 
         return kv[name]
 
@@ -422,6 +424,9 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
     def _to_alarm(self, alarm, value_dict):
         return Alarm(id=alarm['id'], check_id=alarm['check_id'],
             criteria=alarm['criteria'],
+            metadata=alarm.get('metadata'),
+            confd_name=alarm.get('confd_name'),
+            confd_hash=alarm.get('confd_hash'),
             notification_plan_id=alarm.get('notification_plan_id', None), label=alarm.get('label', None),
             driver=self, entity_id=value_dict['entity_id'])
 
@@ -487,6 +492,75 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
                                        data=data)
         return resp.object
 
+
+    ####################
+    ## Suppressions
+    ####################
+
+    def list_suppressions(self, ex_next_marker=None):
+        value_dict = {'url': '/suppressions',
+                      'start_marker': ex_next_marker,
+                      'list_item_mapper': self._to_suppression}
+
+        return LazyList(get_more=self._get_more, value_dict=value_dict)
+
+    def _to_suppression(self, suppression, value_dict):
+        return Suppression(id=suppression['id'],
+                           notification_plans=suppression['notification_plans'],
+                           entities=suppression['entities'],
+                           checks=suppression['checks'],
+                           alarms=suppression['alarms'],
+                           start_time=suppression['start_time'],
+                           end_time=suppression['end_time'],
+                           driver=self)
+
+    def _to_suppression_log(self, suppression_log, value_dict):
+        return SuppressionLog(id=suppression_log['id'],
+                              entity_id=suppression_log['entity_id'],
+                              alarm_id=suppression_log['alarm_id'],
+                              check_id=suppression_log['check_id'],
+                              notification_plan_id=suppression_log['notification_plan_id'],
+                              suppressions=suppression_log['suppressions'],
+                              state=suppression_log['state'],
+                              timestamp=suppression_log['timestamp'],
+                              transaction_id=suppression_log['transaction_id'],
+                              driver=self)
+
+    def get_suppression(self, suppression_id):
+        resp = self.connection.request("/suppressions/%s" % (suppression_id))
+
+        return self._to_suppression(resp.object, {})
+
+    def create_suppression(self, **kwargs):
+        data = {'who': kwargs.get('who'),
+                'why': kwargs.get('why'),
+                'entities': kwargs.get('entities'),
+                'notification_plans': kwargs.get('notification_plans'),
+                'alarms': kwargs.get('alarms'),
+                'checks': kwargs.get('checks'),
+                'start_time': kwargs.get('start_time'),
+                'end_time': kwargs.get('end_time')}
+
+        return self._create("/suppressions", data=data,
+                            coerce=self.get_suppression)
+
+    def delete_suppression(self, suppression, **kwargs):
+        return self._delete(url="/suppressions/%s" % (suppression.id),
+                            kwargs=kwargs)
+
+    def update_suppression(self, suppression, data, **kwargs):
+        return self._update('/suppressions/%s' % (suppression.id),
+            data=data, kwargs=kwargs, coerce=self.get_suppression)
+
+    def list_suppression_logs(self, ex_next_marker=None):
+        value_dict = {'url': '/suppression_logs',
+                      'start_marker': ex_next_marker,
+                      'list_item_mapper': self._to_suppression_log}
+
+        return LazyList(get_more=self._get_more, value_dict=value_dict)
+
+
+
     ####################
     ## Notifications
     ####################
@@ -501,7 +575,9 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
     def _to_notification(self, notification, value_dict):
         return Notification(id=notification['id'], label=notification['label'],
                             type=notification['type'],
-                            details=notification['details'], driver=self)
+                            details=notification['details'],
+                            metadata=notification.get('metadata'),
+                            driver=self)
 
     def get_notification(self, notification_id):
         resp = self.connection.request("/notifications/%s" % (notification_id))
@@ -550,6 +626,7 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
         ok_state = notification_plan.get('ok_state', [])
         return NotificationPlan(id=notification_plan['id'],
             label=notification_plan['label'],
+            metadata=notification_plan.get('metadata'),
             critical_state=critical_state, warning_state=warning_state,
             ok_state=ok_state, driver=self)
 
@@ -607,6 +684,9 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
             'details': obj.get('details', {}),
             'disabled': value_to_bool(obj.get('disabled', '0')),
             'driver': self,
+            'confd_name': obj.get('confd_name'),
+            'confd_hash': obj.get('confd_hash'),
+            'metadata': obj.get('metadata'),
             'entity_id': value_dict['entity_id']})
 
     def list_checks(self, entity, ex_next_marker=None):
@@ -628,6 +708,7 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
                 'type': kwargs.get('type'),
                 'disabled': kwargs.get('disabled', None),
                 'details': kwargs.get('details'),
+                'metadata': kwargs.get('metadata'),
                 }
 
         if 'period' in kwargs:
@@ -877,6 +958,13 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
+    def ex_views_metric_list(self, ex_next_marker=None):
+        value_dict = {'url': '/views/metric_list',
+                      'start_marker': ex_next_marker,
+                      'list_item_mapper': self._to_metric_list_obj}
+
+        return LazyList(get_more=self._get_more, value_dict=value_dict)
+
     def ex_views_agent_host_info(self, agentIds, includes, ex_next_marker=None):
         value_dict = {'url': '/views/agent_host_info',
                       'start_marker': ex_next_marker,
@@ -905,6 +993,19 @@ class RackspaceMonitoringDriver(MonitoringDriver, OpenStackDriverMixin):
         return {'agent_id': data['agent_id'],
                 'host_info': data['host_info']}
 
+    def _to_metric_list_obj(self, data, value_dict):
+        obj = {}
+        obj['entity_id'] = data['entity_id']
+        obj['entity_label'] = data['entity_label']
+        obj['checks'] = []
+
+        for ch in data['checks']:
+            for metric in ch['metrics']:
+                m = self._to_metrics(metric)
+                obj['checks'].append(m)
+
+        return obj
+
     def _to_overview_obj(self, data, value_dict):
         entity = self._to_entity(data['entity'], {})
 
